@@ -4,6 +4,7 @@ from .aes_encrypt import AESEncrypt
 from .basic_crud import BasicCRUD
 from .exceptions import *  # noqa
 from .grants import Grants
+from .metrics import Metrics
 from .ratelimit import RateLimit
 from .service_config import ServiceConfig
 from .service_registry import ServiceRegistry
@@ -11,5 +12,5 @@ from .session_auth import SessionAuth
 from .session_manager import SessionManager, Mutex
 
 __all__ = ('AccessControl', 'AccountSettings', 'AESEncrypt', 'BasicCRUD',
-           'Grants', 'Mutex', 'RateLimit', 'ServiceConfig', 'ServiceRegistry',
-           'SessionAuth', 'SessionManager')
+           'Grants', 'Metrics', 'Mutex', 'RateLimit', 'ServiceConfig',
+           'ServiceRegistry', 'SessionAuth', 'SessionManager')
